@@ -13,7 +13,7 @@ class Keystone(monasca_setup.detection.ServicePlugin):
             'template_dir': template_dir,
             'overwrite': overwrite,
             'service_name': 'identity-service',
-            'process_names': ['keystone-api', 'keystone-main'],
+            'process_names': ['keystone-admin', 'keystone-main'],
             'service_api_url': 'http://localhost:35357/v3',
             'search_pattern': '.*v3\..*'
         }
